@@ -1,8 +1,11 @@
 package AI::Pathfinding::OptimizeMultiple::ScanRun;
 
+use strict;
+use warnings;
+
 use MooX qw/late/;
 
-our $VERSION = '0.0.5';
+our $VERSION = '0.0.6';
 
 has iters => (isa => 'Int', is => 'rw', required => 1);
 has scan_idx => (isa => 'Int', is => 'ro', required => 1);
@@ -32,7 +35,7 @@ iterations.
 
 =head1 VERSION
 
-version 0.0.5
+version 0.0.6
 
 =head1 SYNOPSIS
 
