@@ -1,8 +1,11 @@
 package AI::Pathfinding::OptimizeMultiple::SimulationResults;
 
+use strict;
+use warnings;
+
 use MooX qw/late/;
 
-our $VERSION = '0.0.5';
+our $VERSION = '0.0.6';
 
 has status => (isa => 'Str', is => 'ro', required => 1,);
 has total_iters => (isa => 'Int', is => 'ro', required => 1,);
@@ -30,7 +33,7 @@ AI::Pathfinding::OptimizeMultiple::SimulationResults - the simulation results.
 
 =head1 VERSION
 
-version 0.0.5
+version 0.0.6
 
 =head1 SYNOPSIS
 
